sgoeschl 2005/05/10 03:58:19
Modified: yaafi/src/java/org/apache/fulcrum/yaafi/cli Main.java
Log:
Added a makeAbsolutePath() to determine an absolute path based on the
application working directory
Revision Changes Path
1.7 +14 -1
jakarta-turbine-fulcrum/yaafi/src/java/org/apache/fulcrum/yaafi/cli/Main.java
Index: Main.java
===================================================================
RCS file:
/home/cvs/jakarta-turbine-fulcrum/yaafi/src/java/org/apache/fulcrum/yaafi/cli/Main.java,v
retrieving revision 1.6
retrieving revision 1.7
diff -u -r1.6 -r1.7
--- Main.java 9 May 2005 12:03:17 -0000 1.6
+++ Main.java 10 May 2005 10:58:19 -0000 1.7
@@ -284,7 +284,7 @@
/**
* Locates the file for the given file name.
* @param fileName the filename
* @return the absolute path
*/
public File makeAbsoluteFile( String fileName )
{
@@ -294,6 +294,19 @@
);
}
+ /**
+ * Locates the file for the given file name.
+ * @param fileName the filename
+ * @return an absolute path
+ */
+ public String makeAbsolutePath( String fileName )
+ {
+ return Main.makeAbsoluteFile(
+ new File(this.getApplicationHome()),
+ fileName
+ ).getAbsolutePath();
+ }
+
/////////////////////////////////////////////////////////////////////////
// Generated getters & setters
/////////////////////////////////////////////////////////////////////////
---------------------------------------------------------------------
To unsubscribe, e-mail: [EMAIL PROTECTED]
For additional commands, e-mail: [EMAIL PROTECTED]
@@ -284,7 +284,7 @@
* Locates the file for the given file name.
* @param fileName the filename
- * @return the absolute path
+ * @return an absolute file
*/
public File makeAbsoluteFile( String fileName )